@@ -131,6 +131,10 @@ class AdsAPI(object):
             f = urllib2.urlopen(FACEBOOK_API, urllib.urlencode(args))
             data = json.load(f)
             for idx, val in enumerate(data):
+                # Workaround code for facebook api server error
+                if val['code'] == 500:
+                    logger.error("Facebook api server has some problem.")
+                    val['body'] = '{"error": {"code": 1, "message": "An unknown error occurred", "type": "UnknownError"}}'
                 data[idx] = json.loads(val['body'])
             return data
         except urllib2.HTTPError as e:
